@@ -1,25 +1,33 @@
-import collections
+import sys
 from collections import defaultdict
 import operator
 import itertools
 
+if sys.version_info >= (3, 8, 0):
+    from collections.abc import MutableMapping
+else:
+    from collections import MutableMapping
+
 try:
     from django.apps import apps
+
     get_model = apps.get_model
 except ImportError:
     from django.db.models.loading import get_model
 
 
 def combine_dicts(a, b, op=operator.add):
-    return dict(list(a.items()) + list(b.items()) +
-        [(k, op(a[k], b[k])) for k in set(b) & set(a)])
+    return dict(
+        list(a.items())
+        + list(b.items())
+        + [(k, op(a[k], b[k])) for k in set(b) & set(a)]
+    )
 
 
-DEFAULT_FIELDS = ('actor', 'object')
+DEFAULT_FIELDS = ("actor", "object")
 
 
-class EnrichedActivity(collections.MutableMapping):
-
+class EnrichedActivity(MutableMapping):
     def __init__(self, activity_data):
         self.activity_data = activity_data
         self.not_enriched_data = {}
@@ -43,8 +51,10 @@ class EnrichedActivity(collections.MutableMapping):
         return key
 
     def __repr__(self):
-        return "EnrichedActivity(activity_data=%s, not_enriched_data=%s)" % (str(self.activity_data),
-                                                                             str(self.not_enriched_data))
+        return "EnrichedActivity(activity_data=%s, not_enriched_data=%s)" % (
+            str(self.activity_data),
+            str(self.not_enriched_data),
+        )
 
     def track_not_enriched_field(self, field, value):
         self.not_enriched_data[field] = value
@@ -55,18 +65,20 @@ class EnrichedActivity(collections.MutableMapping):
 
 
 class Enrich(object):
-
     def __init__(self, fields=DEFAULT_FIELDS):
         self.fields = fields
 
     def enrich_aggregated_activities(self, activities):
         references = {}
         for activity in activities:
-            activity['activities'] = self.wrap_activities(activity['activities'])
-            references = combine_dicts(references, self._collect_references(activity['activities'], self.fields))
+            activity["activities"] = self.wrap_activities(activity["activities"])
+            references = combine_dicts(
+                references,
+                self._collect_references(activity["activities"], self.fields),
+            )
         objects = self._fetch_objects(references)
         for activity in activities:
-            self._inject_objects(activity['activities'], objects, self.fields)
+            self._inject_objects(activity["activities"], objects, self.fields)
         return activities
 
     def enrich_activities(self, activities):
@@ -80,34 +92,39 @@ class Enrich(object):
         return [EnrichedActivity(a) for a in activities]
 
     def is_ref(self, activity, field):
-        return len(activity[field].split(':')) == 2 if activity.get(field) else False
+        return len(activity[field].split(":")) == 2 if activity.get(field) else False
 
     def _collect_references(self, activities, fields):
         model_references = defaultdict(list)
         for activity, field in itertools.product(activities, fields):
             if not self.is_ref(activity, field):
                 continue
-            f_ct, f_id = activity[field].split(':')
+            f_ct, f_id = activity[field].split(":")
             model_references[f_ct].append(f_id)
         return model_references
 
     def fetch_model_instances(self, modelClass, pks):
-        '''
+        """
         returns a dict {id:modelInstance} with instances of model modelClass
         and pk in pks
-        '''
-        hook_function_name = 'fetch_%s_instances' % (modelClass._meta.object_name.lower(), )
+        """
+        hook_function_name = "fetch_%s_instances" % (
+            modelClass._meta.object_name.lower(),
+        )
         if hasattr(self, hook_function_name):
             return getattr(self, hook_function_name)(pks)
         qs = modelClass.objects
-        if hasattr(modelClass, 'activity_related_models') and modelClass.activity_related_models() is not None:
+        if (
+            hasattr(modelClass, "activity_related_models")
+            and modelClass.activity_related_models() is not None
+        ):
             qs = qs.select_related(*modelClass.activity_related_models())
         return qs.in_bulk(pks)
 
     def _fetch_objects(self, references):
         objects = defaultdict(list)
         for content_type, ids in references.items():
-            model = get_model(*content_type.split('.'))
+            model = get_model(*content_type.split("."))
             ids = set(ids)
             instances = self.fetch_model_instances(model, ids)
             objects[content_type] = instances
@@ -117,8 +134,8 @@ class Enrich(object):
         for activity, field in itertools.product(activities, fields):
             if not self.is_ref(activity, field):
                 continue
-            f_ct, f_id = activity[field].split(':')
-            model = get_model(*f_ct.split('.'))
+            f_ct, f_id = activity[field].split(":")
+            model = get_model(*f_ct.split("."))
             f_id = model._meta.pk.to_python(f_id)
 
             instance = objects[f_ct].get(f_id)
